==> fluxbox_0.9.12.orig.tar.gz: fluxbox-0.9.12/nls/de_DE/Translation.m <==
$ codeset=ISO-8859-15

$set 1 #Align

1 Unten mitte
2 Unten links
3 Unten rechts
4 Horizontal
5 Links
6 Links unten
7 Links mitte
8 Links oben
9 Relativ
10 Rechts
11 Rechts unten
12 Rechts mitte
13 Rechts oben
14 Oben mitte
15 Oben links
16 Oben rechts
17 Vertikal

$set 2 #BaseDisplay

1 Abbruch... dumping core\n
2 Fahre herunter\n
3 %s:      Signal %d empfangen\n

$set 3 #Common

1 Alpha Transparenz
2 Automatisch Verstecken
3 Compiler kompiliert am
4 Einkompilierte Optionen
5 Compiler
6 Compiler Version
7 Init Datei
8 Tastendefinitionsdatei
9 Mendatei
10 Stildatei (Theme)
11 Standard Einstellungen
12 deaktiviert
13 Fehler
14 Fluxbox Version
15 Durch maximierte Fenster verdecken
16 Sichtbar

$set 4 #Configmenu

1 Kantenglttung (AntiAliasing)
2 Automatisches Hervorheben
3 Klicken zum Hervorheben
4 Klicken zum Fokussieren
5 Flchtige (transient) Fenster dekorieren
6 Desktop mit Mausrad wechseln
7 Fenster nach Desktopwechsel fokussieren
8 Fokustyp
9 Neue Fenster fokussieren
10 Vollstndig Maximieren
11 Bild-Dithering
12 Fenster undurchsichtig bewegen
13 Halb-"schlampiger" Fokus
14 "schlampiger" Fokus
15 Fenster ber Desktopgrenzen verschieben
16 Erzwinge Pseudo-Transparenz
17	Men Alpha Transparenz
18 Transparenz
19 Alpha Transparenz fokussierter Fenster
20 Alpha Transparenz nicht fokussierter Fenster

$set 5 #Ewmh

1 Fataler Fehler: Kein Speicher mehr frei, EWMH client list kann nicht allokiert werden.

$set 6 #FbTkError

1 Warnung! Hhe > 3200 setze Hhe = 3200
2 Warnung! Breite > 3200 setze Breite = 3200
3 Warnung: kann fallback Schriftart nicht laden
4 Fehler beim Allokieren
5 Kann Pixmap nicht erzeugen
6 Kann XImage nicht erzeugen
7 Fehler beim Lesen
8 Warnung: Kann kein gltiges Format fr Alpha finden.
9 Warnung: Kann Alpha Bild nicht erzeugen.
10 Warnung: Kann Alpha Pixmap nicht erzeugen.
11 Kann kein Format fr screen(%d) finden
12 Kein Speicher mehr frei
13 Kein Speicher mehr frei fr "blue buffer".
14 Kein Speicher mehr frei fr "green buffer".
15 Kein Speicher mehr frei fr "red buffer".
16 Kann Stil (Theme) Eintrag nicht lesen
17 Nicht untersttztes visual
18 Benutze Standard Einstellung

$set 7 #Fluxbox

1 Dateiname der Konfigurationsdatei ist ungltig!
2 Kann groupfile nicht laden
3 Kann database nicht laden
4 Versuche es erneut mit
5 Warnung! Kann keinen screen finden auf dem das Fenster dargestellt werden kann!
6 Kann Verzeichnis %s nicht anlegen
7 Kann keine screens finden.\nLuft ein anderer Windowmanager bereits?
8 Fehler beim Parsen des regulren Ausdrucks
9 Fataler Fehler! Es darf nur eine Instanz der Fluxbox Klasse geben
10 Kann nicht zum X-Server verbinden.\nX muss vor Fluxbox gestartet werden.
11 Warnung: X-Server untersttzt Lokalisierung nicht
12 Warnung: Kann Lokalisierung nicht setzen

$set 8 #Gnome

1 Fataler Fehler: Kein Speicher mehr frei, kann GNOME client list nicht allokieren

$set 9 #Keys

1 Tasten: Fehler in Zeile
2 Tasten: Kann Tasten nicht sauber zuweisen!
3 Tasten: Ungltige Taste/Sondertaste (Modifier) in Zeile

$set 10 #Menu

1 Konfiguration
2 Fluxbox Standardmen
3 Beenden
4 Icons
5 Ebene
6 auf Monitor
7 Platzierung
8 Konfiguration neu laden
9 Neu starten
10 xterm

$set 11 #Remember

1 Dekoration
2 Dimension
3 Gehe zum Desktop
4 Ebene
5 Einstellungen merken...
6 Position
7 Beim Schliessen speichern
8 Aufgerollt
9 Auf allen Desktops sichtbar
10 Unbekannter apps Eintrag
11 Momentanen Desktop

$set 12 #Screen

1 BScreen::BScreen: Ein Fehler beim Verbinden zum X-Server ist aufgetreten.\nEin anderer Windowmanager luft bereits auf dem Display 
2 W: %4d x H: %4d
3 W: 0000 x H: 0000
4 BScreen::BScreen: Verwalte screen %d mit visual 0x%lx, Farbtiefe %d\n
5 X: %4d x Y: %4d
6 0: 0000 x 0: 0000

$set 13 #Slit

1 Aktive Slit Programme
2 Eine Position runter bewegen
3 Eine Position hoch bewegen
4 Slit Ausrichtung
5 Slit Ebene
6 Slit auf Monitor
7 Slit Platzierung
8 Slit

$set 14 #Toolbar

1 Momentanen Desktopnamen bearbeiten
2 Iconleiste
3 Alle Fenster
4 Alle Fenster (nur minimierte)
5 Keine
6 Aktueller Desktop (alle Fenster)
7 Aktueller Desktop (nur minimierte)
8 Toolbar Ebene
9 Toolbar auf Monitor
10 Toolbar Platzierung
11 Toolbar
12 Toolbar Grsse (Prozent)
13 Uhr: 24 Stunden Format
14 Uhr: 12 Stunden Format
15 Uhrzeitformat bearbeiten
16 Programm-Icons anzeigen

$set 15 #Window

1 Unbenannt

$set 16 #Windowmenu

1 Schliessen
2 Minimieren
3 Ebene ...
4 Nach Hinten
5 Maximieren
6 Nach Vorne
7 Senden an ...
8 Aufrollen
9 Auf allen Desktops sichtbar

$set 17 #Workspace
1 Desktop %d
2 Desktops
3 Neuer Desktop
4 Letzten Desktop entfernen

$set 18 #bsetroot

1 %s: error: must specify one of: -solid, -mod, -gradient\n
2 Couldn't create pixmap atoms, giving up!
3 %s 2.0: (c) 1997-2000 Brad Hughes\n\n\
-display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    print this help text and exit\n

$set 19 #main

1 Fehler: '-display' braucht ein Argument\n
2 Bad Alloc
3 Bad cast
4 Out of range
5 Runtime error
6 Standard Exception
7 Unbekannter Fehler
8 Fehler: '-log' braucht ein Argument
9 Log Datei
10 Schreibe Log in
11 Fehler: '-rc' braucht ein Argument\n
12 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <string>\t\tBenutze ein anderes $DISPLAY.\n\
-rc <string>\t\t\tBenutze andere Init-Datei.\n\
-version\t\t\tZeige Version an.\n\
-info\t\t\t\tZeige ntzliche Informationen an.\n\
-log <filename>\t\t\tSchreibe Log in Datei.\n\
-help\t\t\t\tZeige diese Hilfe an.\n\n

$set 20 #LayerSet
1 ber Dock
2 Unten
3 Desktop
4 Dock
5 Normal
6 Oben

==> fluxbox_0.9.14.orig.tar.gz: fluxbox-0.9.14.orig/nls/de_DE/Translation.m <==
$ codeset=ISO-8859-15

$set 1 #Align

1 Unten mitte
2 Unten links
3 Unten rechts
4 Horizontal
5 Links
6 Links unten
7 Links mitte
8 Links oben
9 Relativ
10 Rechts
11 Rechts unten
12 Rechts mitte
13 Rechts oben
14 Oben mitte
15 Oben links
16 Oben rechts
17 Vertikal

$set 2 #BaseDisplay

1 Abbruch... dumping core\n
2 Fahre herunter\n
3 %s:      Signal %d empfangen\n

$set 3 #Common

1 Alpha Transparenz
2 Automatisch Verstecken
3 Compiler kompiliert am
4 Einkompilierte Optionen
5 Compiler
6 Compiler Version
7 Init Datei
8 Tastendefinitionsdatei
10 Mendatei
11 Stildatei (Theme)
12 Standard Einstellungen
13 deaktiviert
14 Fehler
15 Fluxbox Version
16 Durch maximierte Fenster verdecken
18 Sichtbar

$set 4 #Configmenu

1 Kantenglttung (AntiAliasing)
2 Automatisches Hervorheben
3 Klicken zum Hervorheben
4 Fokus durch Klick
5 Flchtige (transient) Fenster dekorieren
6 Desktop mit Mausrad wechseln
7 Fenster nach Desktopwechsel fokussieren
8 Fokustyp
9 Neue Fenster fokussieren
10 Vollstndig Maximieren
11 Bild-Dithering
12 Fenster undurchsichtig bewegen
13 Halb-"schlampiger" Fokus
14 MausFokus
15 Fenster ber Desktopgrenzen verschieben
16 Erzwinge Pseudo-Transparenz
17 Men Alpha Transparenz
18 Transparenz
19 Alpha Transparenz fokussierter Fenster
20 Alpha Transparenz nicht fokussierter Fenster

$set 5 #Ewmh

1 Fataler Fehler: Kein Speicher mehr frei, EWMH client list kann nicht allokiert werden.

$set 6 #FbTkError

1 Warnung! Hhe > 3200 setze Hhe = 3200
2 Warnung! Breite > 3200 setze Breite = 3200
3 Warnung: kann fallback Schriftart nicht laden
4 Fehler beim Allokieren
5 Kann Pixmap nicht erzeugen
6 Kann XImage nicht erzeugen
7 Fehler beim Lesen
8 Warnung: Kann kein gltiges Format fr Alpha finden.
9 Warnung: Kann Alpha Bild nicht erzeugen.
10 Warnung: Kann Alpha Pixmap nicht erzeugen.
11 Kann kein Format fr screen(%d) finden
12 Kein Speicher mehr frei
13 Kein Speicher mehr frei fr "blue buffer".
14 Kein Speicher mehr frei fr "green buffer".
15 Kein Speicher mehr frei fr "red buffer".
16 Kann Stil (Theme) Eintrag nicht lesen
17 Nicht untersttztes visual
18 Benutze Standard Einstellung

$set 7 #Fluxbox

1 Dateiname der Konfigurationsdatei ist ungltig!
2 Kann groupfile nicht laden
3 Kann database nicht laden
4 Versuche es erneut mit
5 Warnung! Kann keinen screen finden auf dem das Fenster dargestellt werden kann!
6 Kann Verzeichnis %s nicht anlegen
7 Kann keine screens finden.\nLuft ein anderer Windowmanager bereits?
8 Fehler beim Parsen des regulren Ausdrucks
9 Fataler Fehler! Es darf nur eine Instanz der Fluxbox Klasse geben
10 Kann nicht zum X-Server verbinden.\nX muss vor Fluxbox gestartet werden.
11 Warnung: X-Server untersttzt Lokalisierung nicht
12 Warnung: Kann Lokalisierung nicht setzen

$set 8 #Gnome

1 Fataler Fehler: Kein Speicher mehr frei, kann GNOME client list nicht allokieren

$set 9 #Keys

1 Tasten: Fehler in Zeile
2 Tasten: Kann Tasten nicht sauber zuweisen!
3 Tasten: Ungltige Taste/Sondertaste (Modifier) in Zeile

$set 10 #Menu

1 Konfiguration
2 Fluxbox Standardmen
3 Beenden
4 Icons
5 Ebene
6 auf Monitor
7 Platzierung
8 Konfiguration neu laden
9 Neu starten
10 xterm

$set 11 #Remember

1 Dekoration
2 Dimension
3 Gehe zum Desktop
4 Ebene
5 Einstellungen merken...
6 Position
7 Beim Schliessen speichern
8 Aufgerollt
9 Auf allen Desktops sichtbar
10 Unbekannter apps Eintrag
11 Momentanen Desktop

$set 12 #Screen

1 BScreen::BScreen: Ein Fehler beim Verbinden zum X-Server ist aufgetreten.\nEin anderer Windowmanager luft bereits auf dem Display 
2 W: %4d x H: %4d
3 W: 0000 x H: 0000
4 BScreen::BScreen: Verwalte screen %d mit visual 0x%lx, Farbtiefe %d\n
5 X: %4d x Y: %4d
6 0: 0000 x 0: 0000

$set 13 #Slit

1 Aktive Slit Programme
2 Eine Position runter bewegen
3 Eine Position hoch bewegen
4 Slit Ausrichtung
5 Slit Ebene
6 Slit auf Monitor
7 Slit Platzierung
8 Slit

$set 14 #Toolbar

1 Momentanen Desktopnamen bearbeiten
2 Iconleiste
3 Alle Fenster
4 Alle Fenster (nur minimierte)
5 Keine
6 Aktueller Desktop (alle Fenster)
7 Aktueller Desktop (nur minimierte)
8 Toolbar Ebene
9 Toolbar auf Monitor
10 Toolbar Platzierung
11 Toolbar
12 Toolbar Grsse (Prozent)
13 Uhr: 24 Stunden Format
14 Uhr: 12 Stunden Format
15 Uhrzeitformat bearbeiten
16 Programm-Icons anzeigen

$set 15 #Window

1 Unbenannt

$set 16 #Windowmenu

1 Schliessen
2 Minimieren
3 Ebene ...
4 Nach Hinten
5 Maximieren
6 Nach Vorne
7 Senden an ...
8 Aufrollen
9 Auf allen Desktops sichtbar

$set 17 #Workspace
1 Desktop %d
2 Desktops
3 Neuer Desktop
4 Letzten Desktop entfernen

$set 18 #fbsetroot

1 %s: error: must specify one of: -solid, -mod, -gradient\n
2 Couldn't create pixmap atoms, giving up!
3 %s 2.0: (c) 1997-2000 Brad Hughes\n\n\
-display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    print this help text and exit\n

$set 19 #main

1 Fehler: '-display' braucht ein Argument\n
2 Bad Alloc
3 Bad cast
4 Out of range
5 Runtime error
6 Standard Exception
7 Unbekannter Fehler
8 Fehler: '-log' braucht ein Argument
9 Log Datei
10 Schreibe Log in
11 Fehler: '-rc' braucht ein Argument\n
12 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <string>\t\tBenutze ein anderes $DISPLAY.\n\
-rc <string>\t\t\tBenutze andere Init-Datei.\n\
-version\t\t\tZeige Version an.\n\
-info\t\t\t\tZeige ntzliche Informationen an.\n\
-log <filename>\t\t\tSchreibe Log in Datei.\n\
-help\t\t\t\tZeige diese Hilfe an.\n\n

$set 20 #LayerSet
1 ber Dock
2 Unten
3 Desktop
4 Dock
5 Normal
6 Oben
